import React, { useContext, useEffect, useCallback } from "react";
import {
  ApplicationStateContext,
  ApplicationDispatchContext
} from "../../../state/ApplicationContexts";
import { readMachines } from "../api";
import MachinesList from "./MachinesList";
import { PowerSettingsNew, LastPage } from "@material-ui/icons";

const MachinesContainer = () => {
  const state = useContext(ApplicationStateContext);
  const dispatchActions = useContext(ApplicationDispatchContext);

  const handleReadMachines = useCallback(async () => {
    const machines = await readMachines();
    const data = Object.assign(machines, { loaded: true });
    dispatchActions.onNetworkChange("machines", data);
  }, [dispatchActions]);

  const onClick = machine => () => alert(machine);
  const actions = [
    {
      code: "wake",
      effect: onClick,
      icon: PowerSettingsNew,
      tooltip: "Wake"
    },
    {
      code: "ping",
      effect: onClick,
      icon: LastPage,
      tooltip: "Ping"
    }
  ];

  useEffect(() => {
    if (!state.network.machines.loaded) {
      handleReadMachines();
    }
  }, [handleReadMachines, state.network.machines.loaded]);

  return (
    <MachinesList
      dense={true}
      machines={state.network.machines}
      actions={actions}
    />
  );
};

export default MachinesContainer;
